NeuContainer class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NeuContainer
Constructors
- NeuContainer({Key? key, void onPressed()?, Widget? child, Color? color, Gradient? gradient, double radius = 20, bool inset = false, TapMode tapMode = TapMode.none, EdgeInsets padding = const EdgeInsets.all(8), BoxShape shape = BoxShape.rectangle, required Color boxShadowColor, bool? enabled, bool onStart = false})
-
const
Properties
- boxShadowColor → Color
-
final
- child → Widget?
-
final
- color → Color?
-
final
- enabled → bool?
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inset → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → void Function()?
-
final
- onStart → bool
-
final
- padding → EdgeInsets
-
final
- radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → BoxShape
-
final
- tapMode → TapMode
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NeuContainer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited